# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import experiment_get_params, experiment_list_params, experiment_create_params, experiment_delete_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.experiment_get_response import ExperimentGetResponse
from ..types.experiment_list_response import ExperimentListResponse
from ..types.experiment_create_response import ExperimentCreateResponse
from ..types.experiment_delete_response import ExperimentDeleteResponse

__all__ = ["ExperimentsResource", "AsyncExperimentsResource"]


class ExperimentsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ExperimentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#accessing-raw-response-data-eg-headers
        """
        return ExperimentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ExperimentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#with_streaming_response
        """
        return ExperimentsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        project_id: str,
        description: str | NotGiven = NOT_GIVEN,
        metadata: experiment_create_params.Metadata | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentCreateResponse:
        """
        Create a new Experiment

        Args:
          name: Human-readable name for the experiment

          project_id: Project the experiment is associated with

          description: Succint description of the experiment, if one exists.

          metadata: Metadata relevant to the application configuration from which all experiment
              evaluation runs are derived. E.g. 'llm_model', 'chunk_size'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/2/auto_eval/experiment/create",
            body=maybe_transform(
                {
                    "name": name,
                    "project_id": project_id,
                    "description": description,
                    "metadata": metadata,
                },
                experiment_create_params.ExperimentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentCreateResponse,
        )

    def list(
        self,
        *,
        filters: experiment_list_params.Filters | NotGiven = NOT_GIVEN,
        page_index: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentListResponse:
        """
        List Experiments.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/2/auto_eval/experiment/list",
            body=maybe_transform(
                {
                    "filters": filters,
                    "page_index": page_index,
                    "page_size": page_size,
                },
                experiment_list_params.ExperimentListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentListResponse,
        )

    def delete(
        self,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentDeleteResponse:
        """
        Delete an Experiment.

        Args:
          id: ID of the experiment to delete

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/api/2/auto_eval/experiment/delete",
            body=maybe_transform({"id": id}, experiment_delete_params.ExperimentDeleteParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentDeleteResponse,
        )

    def get(
        self,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentGetResponse:
        """
        Get an Experiment.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/2/auto_eval/experiment/get",
            body=maybe_transform({"id": id}, experiment_get_params.ExperimentGetParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentGetResponse,
        )


class AsyncExperimentsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncExperimentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#accessing-raw-response-data-eg-headers
        """
        return AsyncExperimentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncExperimentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#with_streaming_response
        """
        return AsyncExperimentsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        project_id: str,
        description: str | NotGiven = NOT_GIVEN,
        metadata: experiment_create_params.Metadata | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentCreateResponse:
        """
        Create a new Experiment

        Args:
          name: Human-readable name for the experiment

          project_id: Project the experiment is associated with

          description: Succint description of the experiment, if one exists.

          metadata: Metadata relevant to the application configuration from which all experiment
              evaluation runs are derived. E.g. 'llm_model', 'chunk_size'

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/2/auto_eval/experiment/create",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "project_id": project_id,
                    "description": description,
                    "metadata": metadata,
                },
                experiment_create_params.ExperimentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentCreateResponse,
        )

    async def list(
        self,
        *,
        filters: experiment_list_params.Filters | NotGiven = NOT_GIVEN,
        page_index: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentListResponse:
        """
        List Experiments.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/2/auto_eval/experiment/list",
            body=await async_maybe_transform(
                {
                    "filters": filters,
                    "page_index": page_index,
                    "page_size": page_size,
                },
                experiment_list_params.ExperimentListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentListResponse,
        )

    async def delete(
        self,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentDeleteResponse:
        """
        Delete an Experiment.

        Args:
          id: ID of the experiment to delete

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/api/2/auto_eval/experiment/delete",
            body=await async_maybe_transform({"id": id}, experiment_delete_params.ExperimentDeleteParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentDeleteResponse,
        )

    async def get(
        self,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ExperimentGetResponse:
        """
        Get an Experiment.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/2/auto_eval/experiment/get",
            body=await async_maybe_transform({"id": id}, experiment_get_params.ExperimentGetParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExperimentGetResponse,
        )


class ExperimentsResourceWithRawResponse:
    def __init__(self, experiments: ExperimentsResource) -> None:
        self._experiments = experiments

        self.create = to_raw_response_wrapper(
            experiments.create,
        )
        self.list = to_raw_response_wrapper(
            experiments.list,
        )
        self.delete = to_raw_response_wrapper(
            experiments.delete,
        )
        self.get = to_raw_response_wrapper(
            experiments.get,
        )


class AsyncExperimentsResourceWithRawResponse:
    def __init__(self, experiments: AsyncExperimentsResource) -> None:
        self._experiments = experiments

        self.create = async_to_raw_response_wrapper(
            experiments.create,
        )
        self.list = async_to_raw_response_wrapper(
            experiments.list,
        )
        self.delete = async_to_raw_response_wrapper(
            experiments.delete,
        )
        self.get = async_to_raw_response_wrapper(
            experiments.get,
        )


class ExperimentsResourceWithStreamingResponse:
    def __init__(self, experiments: ExperimentsResource) -> None:
        self._experiments = experiments

        self.create = to_streamed_response_wrapper(
            experiments.create,
        )
        self.list = to_streamed_response_wrapper(
            experiments.list,
        )
        self.delete = to_streamed_response_wrapper(
            experiments.delete,
        )
        self.get = to_streamed_response_wrapper(
            experiments.get,
        )


class AsyncExperimentsResourceWithStreamingResponse:
    def __init__(self, experiments: AsyncExperimentsResource) -> None:
        self._experiments = experiments

        self.create = async_to_streamed_response_wrapper(
            experiments.create,
        )
        self.list = async_to_streamed_response_wrapper(
            experiments.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            experiments.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            experiments.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["DatasetListParams", "Filters"]


class DatasetListParams(TypedDict, total=False):
    filters: Filters
    """Filter listed datasets by ALL filters specified"""


class Filters(TypedDict, total=False):
    project_id: Annotated[str, PropertyInfo(alias="projectId")]
    """filter datasets associated with the project"""

    query: str
    """search query substring match for name and description"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EvaluationEvaluateDatasetResponse", "Metric", "MetricScore", "MetricScoreMetric"]


class Metric(BaseModel):
    id: Optional[str] = None

    deployment_status: Optional[
        Literal[
            "MODEL_DEPLOYMENT_STATUS_UNSPECIFIED",
            "MODEL_DEPLOYMENT_STATUS_PENDING",
            "MODEL_DEPLOYMENT_STATUS_ONLINE",
            "MODEL_DEPLOYMENT_STATUS_OFFLINE",
            "MODEL_DEPLOYMENT_STATUS_PAUSED",
        ]
    ] = FieldInfo(alias="deploymentStatus", default=None)

    description: Optional[str] = None

    name: Optional[str] = None


class MetricScoreMetric(BaseModel):
    id: Optional[str] = None

    deployment_status: Optional[
        Literal[
            "MODEL_DEPLOYMENT_STATUS_UNSPECIFIED",
            "MODEL_DEPLOYMENT_STATUS_PENDING",
            "MODEL_DEPLOYMENT_STATUS_ONLINE",
            "MODEL_DEPLOYMENT_STATUS_OFFLINE",
            "MODEL_DEPLOYMENT_STATUS_PAUSED",
        ]
    ] = FieldInfo(alias="deploymentStatus", default=None)

    description: Optional[str] = None

    name: Optional[str] = None


class MetricScore(BaseModel):
    metric: MetricScoreMetric

    scores: List[float]


class EvaluationEvaluateDatasetResponse(BaseModel):
    metric: Metric

    metric_scores: List[MetricScore] = FieldInfo(alias="metricScores")

    run_id: str = FieldInfo(alias="runId")

    scores: List[float]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["DatasetFinalizeFileUploadParams", "S3PresignedPost"]


class DatasetFinalizeFileUploadParams(TypedDict, total=False):
    dataset_id: Required[Annotated[str, PropertyInfo(alias="datasetId")]]
    """The ID of the dataset corresponding to the file"""

    s3_presigned_post: Required[Annotated[S3PresignedPost, PropertyInfo(alias="s3PresignedPost")]]
    """The pre-signed S3 URL where the file was uploadeded"""


class S3PresignedPost(TypedDict, total=False):
    fields: Required[Dict[str, str]]
    """Fields required for the S3 presigned POST request generated by s3 sdk."""

    url: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    label_dataset_job_create_params,
    label_dataset_job_submit_params,
    label_dataset_job_get_status_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.label_dataset_job_create_response import LabelDatasetJobCreateResponse
from ..types.label_dataset_job_submit_response import LabelDatasetJobSubmitResponse
from ..types.label_dataset_job_get_status_response import LabelDatasetJobGetStatusResponse

__all__ = ["LabelDatasetJobsResource", "AsyncLabelDatasetJobsResource"]


class LabelDatasetJobsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LabelDatasetJobsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#accessing-raw-response-data-eg-headers
        """
        return LabelDatasetJobsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LabelDatasetJobsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#with_streaming_response
        """
        return LabelDatasetJobsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        pseudo_label_job_config: label_dataset_job_create_params.PseudoLabelJobConfig,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LabelDatasetJobCreateResponse:
        """
        Step 1 of 2: Create a new job configuration for LLM Judge labeling, to be
        subsequently submitted by calling SubmitPseudoLabelJob.

        Args:
          pseudo_label_job_config: Partial configuration containing updates via its non-null fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/2/auto_eval/pseudo_label_job/create",
            body=maybe_transform(
                {"pseudo_label_job_config": pseudo_label_job_config},
                label_dataset_job_create_params.LabelDatasetJobCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabelDatasetJobCreateResponse,
        )

    def get_status(
        self,
        *,
        job_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LabelDatasetJobGetStatusResponse:
        """
        Get the status of an existing job, including any results.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/2/auto_eval/pseudo_label_job/get_status",
            body=maybe_transform(
                {"job_id": job_id}, label_dataset_job_get_status_params.LabelDatasetJobGetStatusParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabelDatasetJobGetStatusResponse,
        )

    def submit(
        self,
        *,
        job_id: str,
        pseudo_label_job_config: label_dataset_job_submit_params.PseudoLabelJobConfig,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LabelDatasetJobSubmitResponse:
        """
        Step 2 of 2: Submit the job configuration created by CreatePseudoLabelJob to
        initiate an LLM Judge labeling job.

        Args:
          pseudo_label_job_config: The pseudo-labeling job configuration.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/2/auto_eval/pseudo_label_job/submit",
            body=maybe_transform(
                {
                    "job_id": job_id,
                    "pseudo_label_job_config": pseudo_label_job_config,
                },
                label_dataset_job_submit_params.LabelDatasetJobSubmitParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabelDatasetJobSubmitResponse,
        )


class AsyncLabelDatasetJobsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLabelDatasetJobsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLabelDatasetJobsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLabelDatasetJobsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/lastmile-ai/lastmile-python#with_streaming_response
        """
        return AsyncLabelDatasetJobsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        pseudo_label_job_config: label_dataset_job_create_params.PseudoLabelJobConfig,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LabelDatasetJobCreateResponse:
        """
        Step 1 of 2: Create a new job configuration for LLM Judge labeling, to be
        subsequently submitted by calling SubmitPseudoLabelJob.

        Args:
          pseudo_label_job_config: Partial configuration containing updates via its non-null fields.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/2/auto_eval/pseudo_label_job/create",
            body=await async_maybe_transform(
                {"pseudo_label_job_config": pseudo_label_job_config},
                label_dataset_job_create_params.LabelDatasetJobCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabelDatasetJobCreateResponse,
        )

    async def get_status(
        self,
        *,
        job_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LabelDatasetJobGetStatusResponse:
        """
        Get the status of an existing job, including any results.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/2/auto_eval/pseudo_label_job/get_status",
            body=await async_maybe_transform(
                {"job_id": job_id}, label_dataset_job_get_status_params.LabelDatasetJobGetStatusParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabelDatasetJobGetStatusResponse,
        )

    async def submit(
        self,
        *,
        job_id: str,
        pseudo_label_job_config: label_dataset_job_submit_params.PseudoLabelJobConfig,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LabelDatasetJobSubmitResponse:
        """
        Step 2 of 2: Submit the job configuration created by CreatePseudoLabelJob to
        initiate an LLM Judge labeling job.

        Args:
          pseudo_label_job_config: The pseudo-labeling job configuration.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/2/auto_eval/pseudo_label_job/submit",
            body=await async_maybe_transform(
                {
                    "job_id": job_id,
                    "pseudo_label_job_config": pseudo_label_job_config,
                },
                label_dataset_job_submit_params.LabelDatasetJobSubmitParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabelDatasetJobSubmitResponse,
        )


class LabelDatasetJobsResourceWithRawResponse:
    def __init__(self, label_dataset_jobs: LabelDatasetJobsResource) -> None:
        self._label_dataset_jobs = label_dataset_jobs

        self.create = to_raw_response_wrapper(
            label_dataset_jobs.create,
        )
        self.get_status = to_raw_response_wrapper(
            label_dataset_jobs.get_status,
        )
        self.submit = to_raw_response_wrapper(
            label_dataset_jobs.submit,
        )


class AsyncLabelDatasetJobsResourceWithRawResponse:
    def __init__(self, label_dataset_jobs: AsyncLabelDatasetJobsResource) -> None:
        self._label_dataset_jobs = label_dataset_jobs

        self.create = async_to_raw_response_wrapper(
            label_dataset_jobs.create,
        )
        self.get_status = async_to_raw_response_wrapper(
            label_dataset_jobs.get_status,
        )
        self.submit = async_to_raw_response_wrapper(
            label_dataset_jobs.submit,
        )


class LabelDatasetJobsResourceWithStreamingResponse:
    def __init__(self, label_dataset_jobs: LabelDatasetJobsResource) -> None:
        self._label_dataset_jobs = label_dataset_jobs

        self.create = to_streamed_response_wrapper(
            label_dataset_jobs.create,
        )
        self.get_status = to_streamed_response_wrapper(
            label_dataset_jobs.get_status,
        )
        self.submit = to_streamed_response_wrapper(
            label_dataset_jobs.submit,
        )


class AsyncLabelDatasetJobsResourceWithStreamingResponse:
    def __init__(self, label_dataset_jobs: AsyncLabelDatasetJobsResource) -> None:
        self._label_dataset_jobs = label_dataset_jobs

        self.create = async_to_streamed_response_wrapper(
            label_dataset_jobs.create,
        )
        self.get_status = async_to_streamed_response_wrapper(
            label_dataset_jobs.get_status,
        )
        self.submit = async_to_streamed_response_wrapper(
            label_dataset_jobs.submit,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DatasetGetResponse", "Dataset", "DatasetColumn", "DatasetLabelState"]


class DatasetColumn(BaseModel):
    id: str
    """The ID of the dataset file."""

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    index: int
    """Index of the column within the dataset file."""

    literal_name: str = FieldInfo(alias="literalName")
    """The literal name for the column."""

    updated_at: datetime = FieldInfo(alias="updatedAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    dtype: Optional[
        Literal[
            "DATASET_COLUMN_D_TYPE_UNSPECIFIED",
            "DATASET_COLUMN_D_TYPE_INT32",
            "DATASET_COLUMN_D_TYPE_INT64",
            "DATASET_COLUMN_D_TYPE_FLOAT32",
            "DATASET_COLUMN_D_TYPE_FLOAT64",
            "DATASET_COLUMN_D_TYPE_STRING",
            "DATASET_COLUMN_D_TYPE_BYTES",
            "DATASET_COLUMN_D_TYPE_ANY",
            "DATASET_COLUMN_D_TYPE_LIST_OF_STRINGS",
            "DATASET_COLUMN_D_TYPE_BOOLEAN",
        ]
    ] = None
    """Datatypes for a column in a dataset file.

    We likely don't need everything here, but it's good to be explicit, for example
    to avoid unknowingly coercing int64 values into int32. Encoding for text is
    UTF_8 unless indicated otherwise.
    """


class DatasetLabelState(BaseModel):
    labeling_status: Literal[
        "JOB_STATUS_UNSPECIFIED",
        "JOB_STATUS_QUEUED",
        "JOB_STATUS_RUNNING",
        "JOB_STATUS_COMPLETED",
        "JOB_STATUS_CANCELLED",
        "JOB_STATUS_FAILED",
    ] = FieldInfo(alias="labelingStatus")
    """The status of the latest general pseudo-labeling job for the dataset"""

    prompt_template: str = FieldInfo(alias="promptTemplate")
    """aka user general instructions"""

    error: Optional[str] = None
    """if the labeling status is error, this field may contain an error message"""


class Dataset(BaseModel):
    id: str
    """The ID of the dataset."""

    columns: List[DatasetColumn]

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    initialization_status: Literal[
        "JOB_STATUS_UNSPECIFIED",
        "JOB_STATUS_QUEUED",
        "JOB_STATUS_RUNNING",
        "JOB_STATUS_COMPLETED",
        "JOB_STATUS_CANCELLED",
        "JOB_STATUS_FAILED",
    ] = FieldInfo(alias="initializationStatus")

    num_cols: int = FieldInfo(alias="numCols")

    num_rows: int = FieldInfo(alias="numRows")

    owner_user_id: str = FieldInfo(alias="ownerUserId")
    """The ID of the user who owns the dataset."""

    updated_at: datetime = FieldInfo(alias="updatedAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    description: Optional[str] = None
    """Human-readable description of the dataset, if one exists."""

    initialization_error: Optional[str] = FieldInfo(alias="initializationError", default=None)

    label_state: Optional[DatasetLabelState] = FieldInfo(alias="labelState", default=None)
    """The state of the latest labeling job for the dataset"""

    name: Optional[str] = None
    """Human-readable name for the dataset, if one exists."""


class DatasetGetResponse(BaseModel):
    dataset: Dataset
    """
    A Dataset in the most basic sense: metadata and ownership, but nothing tied to
    its data.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ProjectGetResponse", "Project"]


class Project(BaseModel):
    id: str

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    name: str

    updated_at: datetime = FieldInfo(alias="updatedAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    creator_id: Optional[str] = FieldInfo(alias="creatorId", default=None)

    deleted_at: Optional[datetime] = FieldInfo(alias="deletedAt", default=None)
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    description: Optional[str] = None

    organization_id: Optional[str] = FieldInfo(alias="organizationId", default=None)

    organization_name: Optional[str] = FieldInfo(alias="organizationName", default=None)


class ProjectGetResponse(BaseModel):
    project: Project



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EvaluationEvaluateResponse", "Metric"]


class Metric(BaseModel):
    id: Optional[str] = None

    deployment_status: Optional[
        Literal[
            "MODEL_DEPLOYMENT_STATUS_UNSPECIFIED",
            "MODEL_DEPLOYMENT_STATUS_PENDING",
            "MODEL_DEPLOYMENT_STATUS_ONLINE",
            "MODEL_DEPLOYMENT_STATUS_OFFLINE",
            "MODEL_DEPLOYMENT_STATUS_PAUSED",
        ]
    ] = FieldInfo(alias="deploymentStatus", default=None)

    description: Optional[str] = None

    name: Optional[str] = None


class EvaluationEvaluateResponse(BaseModel):
    metric: Metric

    scores: List[float]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "FineTuneJobListBaseModelsResponse",
    "Model",
    "ModelMetricBaseModel",
    "ModelModelCard",
    "ModelModelCardTrainingProgress",
]


class ModelMetricBaseModel(BaseModel):
    id: str

    base_model_architecture: Literal[
        "BASE_MODEL_ARCHITECTURE_UNSPECIFIED",
        "BASE_MODEL_ARCHITECTURE_ALBERTA_XS",
        "BASE_MODEL_ARCHITECTURE_ALBERTA_LC",
        "BASE_MODEL_ARCHITECTURE_DEBERTA_V3",
        "BASE_MODEL_ARCHITECTURE_ST_SIMILARITY",
        "BASE_MODEL_ARCHITECTURE_MODERNBERT_BASE",
        "BASE_MODEL_ARCHITECTURE_MODERNBERT_LARGE",
        "BASE_MODEL_ARCHITECTURE_MODERNBERT_LARGE_GNN",
    ] = FieldInfo(alias="baseModelArchitecture")
    """Keep in sync with www/prisma/schema.prisma:AEBaseModelArchitecture"""

    model_id: str = FieldInfo(alias="modelId")

    base_evaluation_metric: Optional[
        Literal[
            "BASE_EVALUATION_METRIC_UNSPECIFIED",
            "BASE_EVALUATION_METRIC_FAITHFULNESS",
            "BASE_EVALUATION_METRIC_RELEVANCE",
            "BASE_EVALUATION_METRIC_TOXICITY",
            "BASE_EVALUATION_METRIC_QA",
            "BASE_EVALUATION_METRIC_SUMMARIZATION",
        ]
    ] = FieldInfo(alias="baseEvaluationMetric", default=None)
    """Keep in sync with www/prisma/schema.prisma:AEBaseEvaluationMetric"""


class ModelModelCardTrainingProgress(BaseModel):
    accuracy: float

    epoch: int

    job_id: str = FieldInfo(alias="jobId")

    loss: float

    progress: float

    timestamp: datetime
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """


class ModelModelCard(BaseModel):
    base_model_architecture: Literal[
        "BASE_MODEL_ARCHITECTURE_UNSPECIFIED",
        "BASE_MODEL_ARCHITECTURE_ALBERTA_XS",
        "BASE_MODEL_ARCHITECTURE_ALBERTA_LC",
        "BASE_MODEL_ARCHITECTURE_DEBERTA_V3",
        "BASE_MODEL_ARCHITECTURE_ST_SIMILARITY",
        "BASE_MODEL_ARCHITECTURE_MODERNBERT_BASE",
        "BASE_MODEL_ARCHITECTURE_MODERNBERT_LARGE",
        "BASE_MODEL_ARCHITECTURE_MODERNBERT_LARGE_GNN",
    ] = FieldInfo(alias="baseModelArchitecture")
    """Keep in sync with www/prisma/schema.prisma:AEBaseModelArchitecture"""

    columns: List[str]

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    deployment_status: Literal[
        "MODEL_DEPLOYMENT_STATUS_UNSPECIFIED",
        "MODEL_DEPLOYMENT_STATUS_PENDING",
        "MODEL_DEPLOYMENT_STATUS_ONLINE",
        "MODEL_DEPLOYMENT_STATUS_OFFLINE",
        "MODEL_DEPLOYMENT_STATUS_PAUSED",
    ] = FieldInfo(alias="deploymentStatus")

    description: str

    model_id: str = FieldInfo(alias="modelId")

    model_size: int = FieldInfo(alias="modelSize")

    name: str

    purpose: str

    tags: List[str]

    training_progress: ModelModelCardTrainingProgress = FieldInfo(alias="trainingProgress")
    """Progress metrics from model training."""

    updated_at: datetime = FieldInfo(alias="updatedAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    values: Dict[str, str]

    base_evaluation_metric: Optional[
        Literal[
            "BASE_EVALUATION_METRIC_UNSPECIFIED",
            "BASE_EVALUATION_METRIC_FAITHFULNESS",
            "BASE_EVALUATION_METRIC_RELEVANCE",
            "BASE_EVALUATION_METRIC_TOXICITY",
            "BASE_EVALUATION_METRIC_QA",
            "BASE_EVALUATION_METRIC_SUMMARIZATION",
        ]
    ] = FieldInfo(alias="baseEvaluationMetric", default=None)
    """Keep in sync with www/prisma/schema.prisma:AEBaseEvaluationMetric"""


class Model(BaseModel):
    id: str

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    metric_base_model: ModelMetricBaseModel = FieldInfo(alias="metricBaseModel")
    """Information about a base model corresponding to a metric"""

    updated_at: datetime = FieldInfo(alias="updatedAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    deleted_at: Optional[datetime] = FieldInfo(alias="deletedAt", default=None)
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    model_card: Optional[ModelModelCard] = FieldInfo(alias="modelCard", default=None)

    user_id: Optional[str] = FieldInfo(alias="userId", default=None)


class FineTuneJobListBaseModelsResponse(BaseModel):
    models: List[Model]



#!/usr/bin/env -S rye run python

import os
from datetime import datetime

import pandas as pd

from lastmile.lib.auto_eval import Metric, AutoEval, BuiltinMetrics

# Use to deduplicate entity names per script run
NOW_DATE_STRING = datetime.now().strftime("%Y-%m-%d %H:%M:%S")


def main() -> None:
    client = AutoEval(
        # This is the default and can be omitted
        api_token=os.environ.get("LASTMILE_API_KEY"),
    )

    run_evaluation_examples(client)


def basic_example(client: AutoEval) -> None:
    input_df = pd.DataFrame(
        {
            "input": [
                "Can you tell me the weight limit for carry-on bags?",
                "What gate is my flight SA795 departing from?",
                "Can I bring my pet on the plane?",
            ],
            "output": [
                "The weight limit for carry-on bags is 7kg.",
                "Your flight SA795 is departing from JFK at 6:30PM.",
                "Yes, you can bring your pet, but it must fit under the seat in front of you and there is a pet fee.",
            ],
            "ground_truth": [
                "7kg",
                "SA795: JFK Terminal 4, Gate 42, 6:30PM departure",
                "Pets are not allowed on StrikeAir flights.",
            ],
        }
    )

    output_df = client.evaluate_data(input_df, BuiltinMetrics.FAITHFULNESS)
    print(output_df)
    #                                                input                                             output                                      ground_truth  Faithfulness_score
    # 0  Can you tell me the weight limit for carry-on ...         The weight limit for carry-on bags is 7kg.                                               7kg            0.998831
    # 1       What gate is my flight SA795 departing from?  Your flight SA795 is departing from JFK at 6:3...  SA795: JFK Terminal 4, Gate 42, 6:30PM departure            0.998952
    # 2                   Can I bring my pet on the plane?  Yes, you can bring your pet, but it must fit u...        Pets are not allowed on StrikeAir flights.            0.000892


def run_dataset_examples(client: AutoEval) -> None:
    # Create a dataset
    dataset_id = client.upload_dataset(
        name=f"My First Dataset, {NOW_DATE_STRING}",
        description="This is an example dataset",
        file_path="examples/halueval_sample.csv",
    )
    print(f"Successfully created dataset with id {dataset_id}")

    # Download the dataset
    new_dataset = client.download_dataset(dataset_id, "./test-downloaded.csv")
    print(f"Successfully downloaded dataset with {new_dataset.shape[0]} rows")

    # List datasets
    datasets = client.list_datasets()
    print(f"Found {len(datasets)} datasets")

    # List datasets with query filter
    filtered_datasets = client.list_datasets(query="My First Dataset")
    print(f"Found {len(filtered_datasets)} datasets with query filter")

    # Label the dataset with few-shot examples
    print("Labeling dataset with few-shot examples")
    client.label_dataset(
        dataset_id=dataset_id,
        prompt_template=BuiltinMetrics.FAITHFULNESS,
        few_shot_examples=pd.DataFrame(
            {
                "input": ["This is a test input"],
                "output": ["This is a test output"],
                "ground_truth": ["This is a test"],
                "label": [1],
            }
        ),
        wait_for_completion=True,
    )
    print("Successfully labeled dataset")

    # Delete the dataset
    client.delete_dataset(dataset_id)
    print(f"Successfully deleted dataset {dataset_id}")


def run_evaluation_examples(client: AutoEval) -> None:
    # Create eval project
    eval_project = client.create_project(
        name=f"My First Eval Project, {NOW_DATE_STRING}", description="An example eval project"
    )
    client.project_id = eval_project.id

    # List Metrics
    metrics = client.list_metrics()
    print(f"Found {len(metrics)} total metrics: {[m.name or m.id for m in metrics if m.name or m.id]}")

    # Evaluate data
    data_eval = client.evaluate_data(
        data=pd.DataFrame(
            {
                "input": ["This is a test input"],
                "output": ["This is a test output"],
                "ground_truth": ["This is a test"],
            }
        ),
        metrics=[BuiltinMetrics.FAITHFULNESS],
    )
    print(data_eval)

    # Create a dataset to evaluate
    dataset_id = client.upload_dataset(
        name=f"My First Eval Dataset, {NOW_DATE_STRING}",
        description="This is an example eval dataset",
        file_path="examples/halueval_sample.csv",
    )

    # Create an experiment
    experiment = client.create_experiment(
        name=f"My First Eval Experiment, {NOW_DATE_STRING}",
        description="This is an example eval experiment",
        metadata={"chunk_size": 100},
    )
    print(f"Created experiment with id {experiment.id}")

    # Evaluate dataset in the experiment
    dataset_eval = client.evaluate_dataset(
        dataset_id=dataset_id,
        metrics=[BuiltinMetrics.FAITHFULNESS, Metric(name="Relevance")],
        experiment_id=experiment.id,
        metadata={"model": "gpt-4o"},
    )
    print("Dataset Eval: ", dataset_eval)

    # Evaluate run in the experiment
    run_eval = client.create_evaluation_run(
        data=pd.DataFrame(
            {
                "input": ["This is a test input in an experiment"],
                "output": ["This is a test output in an experiment"],
                "ground_truth": ["This is a test in an experiment"],
            }
        ),
        experiment_id=experiment.id,
        metrics=[BuiltinMetrics.FAITHFULNESS, Metric(name="Relevance")],
        metadata={"model": "gpt-3.5-turbo"},
    )
    print("Run Eval: ", run_eval)

    # Run eval outside of an experiment
    standalone_eval = client.create_evaluation_run(
        data=pd.DataFrame(
            {
                "input": ["This is a standalone test input"],
                "output": ["This is a standalone test output"],
                "ground_truth": ["This is a standalone test"],
            }
        ),
        metrics=[Metric(id="cm2plr07q000ipkr4o8qhj4oe")],  # Faithfulness
        metadata={"model": "gpt-4"},
    )
    print("Standalone Eval: ", standalone_eval)


if __name__ == "__main__":
    main()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LabelDatasetJobCreateParams", "PseudoLabelJobConfig", "PseudoLabelJobConfigPromptTemplate"]


class LabelDatasetJobCreateParams(TypedDict, total=False):
    pseudo_label_job_config: Required[Annotated[PseudoLabelJobConfig, PropertyInfo(alias="pseudoLabelJobConfig")]]
    """Partial configuration containing updates via its non-null fields."""


class PseudoLabelJobConfigPromptTemplate(TypedDict, total=False):
    id: Required[str]

    template: Required[str]
    """The template string that defines the prompt"""


class PseudoLabelJobConfig(TypedDict, total=False):
    base_evaluation_metric: Required[
        Annotated[
            Literal[
                "BASE_EVALUATION_METRIC_UNSPECIFIED",
                "BASE_EVALUATION_METRIC_FAITHFULNESS",
                "BASE_EVALUATION_METRIC_RELEVANCE",
                "BASE_EVALUATION_METRIC_TOXICITY",
                "BASE_EVALUATION_METRIC_QA",
                "BASE_EVALUATION_METRIC_SUMMARIZATION",
            ],
            PropertyInfo(alias="baseEvaluationMetric"),
        ]
    ]
    """Reserved field. Do not use at the moment."""

    dataset_id: Required[Annotated[str, PropertyInfo(alias="datasetId")]]
    """ID of the main dataset to be pseudo-labeled"""

    prompt_template: Required[Annotated[PseudoLabelJobConfigPromptTemplate, PropertyInfo(alias="promptTemplate")]]

    selected_columns: Required[Annotated[List[str], PropertyInfo(alias="selectedColumns")]]

    skip_active_labeling: Required[Annotated[bool, PropertyInfo(alias="skipActiveLabeling")]]
    """
    If true, skip active labeling, which involves an intermediate Dataset created
    for human labeling.
    """

    active_labeled_dataset_id: Annotated[str, PropertyInfo(alias="activeLabeledDatasetId")]
    """ID of the actively labeled dataset.

    Optional. If null, this job is for active learning.
    """

    description: str
    """Optional description for the job."""

    few_shot_dataset_id: Annotated[str, PropertyInfo(alias="fewShotDatasetId")]
    """ID of the dataset containing few-shot examples. Optional."""

    name: str
    """Optional name for the job."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EvaluationEvaluateParams", "Metric", "Metadata"]


class EvaluationEvaluateParams(TypedDict, total=False):
    ground_truth: Required[Annotated[List[str], PropertyInfo(alias="groundTruth")]]

    input: Required[List[str]]

    metric: Required[Metric]

    output: Required[List[str]]

    metadata: Metadata
    """
    Common metadata relevant to the application configuration from which all request
    inputs were derived. E.g. 'llm_model', 'chunk_size'
    """

    project_id: Annotated[str, PropertyInfo(alias="projectId")]
    """The project where evaluation inference logs will be stored"""


class Metric(TypedDict, total=False):
    id: str

    deployment_status: Annotated[
        Literal[
            "MODEL_DEPLOYMENT_STATUS_UNSPECIFIED",
            "MODEL_DEPLOYMENT_STATUS_PENDING",
            "MODEL_DEPLOYMENT_STATUS_ONLINE",
            "MODEL_DEPLOYMENT_STATUS_OFFLINE",
            "MODEL_DEPLOYMENT_STATUS_PAUSED",
        ],
        PropertyInfo(alias="deploymentStatus"),
    ]

    description: str

    name: str


class Metadata(TypedDict, total=False):
    fields: Required[Dict[str, Dict[str, object]]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DatasetGetViewResponse", "DatasetView", "DatasetViewColumn", "DatasetViewData"]


class DatasetViewColumn(BaseModel):
    id: str
    """The ID of the dataset file."""

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    index: int
    """Index of the column within the dataset file."""

    literal_name: str = FieldInfo(alias="literalName")
    """The literal name for the column."""

    updated_at: datetime = FieldInfo(alias="updatedAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    dtype: Optional[
        Literal[
            "DATASET_COLUMN_D_TYPE_UNSPECIFIED",
            "DATASET_COLUMN_D_TYPE_INT32",
            "DATASET_COLUMN_D_TYPE_INT64",
            "DATASET_COLUMN_D_TYPE_FLOAT32",
            "DATASET_COLUMN_D_TYPE_FLOAT64",
            "DATASET_COLUMN_D_TYPE_STRING",
            "DATASET_COLUMN_D_TYPE_BYTES",
            "DATASET_COLUMN_D_TYPE_ANY",
            "DATASET_COLUMN_D_TYPE_LIST_OF_STRINGS",
            "DATASET_COLUMN_D_TYPE_BOOLEAN",
        ]
    ] = None
    """Datatypes for a column in a dataset file.

    We likely don't need everything here, but it's good to be explicit, for example
    to avoid unknowingly coercing int64 values into int32. Encoding for text is
    UTF_8 unless indicated otherwise.
    """


class DatasetViewData(BaseModel):
    id: str

    row_values: List[Dict[str, object]] = FieldInfo(alias="rowValues")


class DatasetView(BaseModel):
    columns: List[DatasetViewColumn]

    data: List[DatasetViewData]

    num_cols: int = FieldInfo(alias="numCols")

    num_rows: int = FieldInfo(alias="numRows")


class DatasetGetViewResponse(BaseModel):
    dataset_file_id: str = FieldInfo(alias="datasetFileId")

    dataset_id: str = FieldInfo(alias="datasetId")

    dataset_version_key: str = FieldInfo(alias="datasetVersionKey")
    """dataset version key"""

    dataset_view: DatasetView = FieldInfo(alias="datasetView")

    next_page_cursor: Optional[str] = FieldInfo(alias="nextPageCursor", default=None)
    """A cursor for the next page in the pagination, if one exists."""

    previous_page_cursor: Optional[str] = FieldInfo(alias="previousPageCursor", default=None)
    """A cursor for the previous page in the pagination, if one exists."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ProjectListParams", "Filters"]


class ProjectListParams(TypedDict, total=False):
    filters: Filters


class Filters(TypedDict, total=False):
    can_contribute: Annotated[bool, PropertyInfo(alias="canContribute")]
    """only return projects to which the viewer can contribute"""

    organization_id: Annotated[str, PropertyInfo(alias="organizationId")]
    """search only projects associated with specific organization"""

    query: str
    """search query substring match for name and description"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "EvaluationGetRunResponse",
    "EvaluationRun",
    "EvaluationRunAggregateMetric",
    "EvaluationRunAggregateMetricMetric",
    "EvaluationRunMetadata",
]


class EvaluationRunAggregateMetricMetric(BaseModel):
    id: Optional[str] = None

    deployment_status: Optional[
        Literal[
            "MODEL_DEPLOYMENT_STATUS_UNSPECIFIED",
            "MODEL_DEPLOYMENT_STATUS_PENDING",
            "MODEL_DEPLOYMENT_STATUS_ONLINE",
            "MODEL_DEPLOYMENT_STATUS_OFFLINE",
            "MODEL_DEPLOYMENT_STATUS_PAUSED",
        ]
    ] = FieldInfo(alias="deploymentStatus", default=None)

    description: Optional[str] = None

    name: Optional[str] = None


class EvaluationRunAggregateMetric(BaseModel):
    aggregate_method: Literal[
        "METRIC_AGGREGATE_METHOD_UNSPECIFIED", "METRIC_AGGREGATE_METHOD_SUM", "METRIC_AGGREGATE_METHOD_AVG"
    ] = FieldInfo(alias="aggregateMethod")

    metric: EvaluationRunAggregateMetricMetric

    score: float


class EvaluationRunMetadata(BaseModel):
    fields: Dict[str, Dict[str, object]]


class EvaluationRun(BaseModel):
    id: str

    aggregate_metrics: List[EvaluationRunAggregateMetric] = FieldInfo(alias="aggregateMetrics")

    created_at: datetime = FieldInfo(alias="createdAt")
    """
    A summary is retrieved for a time range from start_time to end_time If no
    end_time is provided, current time is used
    """

    name: str

    num_rows: int = FieldInfo(alias="numRows")

    project_id: str = FieldInfo(alias="projectId")

    run_type: Literal[
        "EVALUATION_RUN_TYPE_UNSPECIFIED", "EVALUATION_RUN_TYPE_ADHOC", "EVALUATION_RUN_TYPE_EXPERIMENT"
    ] = FieldInfo(alias="runType")

    creator_id: Optional[str] = FieldInfo(alias="creatorId", default=None)

    experiment_id: Optional[str] = FieldInfo(alias="experimentId", default=None)

    experiment_name: Optional[str] = FieldInfo(alias="experimentName", default=None)

    metadata: Optional[EvaluationRunMetadata] = None

    result_dataset_id: Optional[str] = FieldInfo(alias="resultDatasetId", default=None)

    source_dataset_id: Optional[str] = FieldInfo(alias="sourceDatasetId", default=None)


class EvaluationGetRunResponse(BaseModel):
    evaluation_run: EvaluationRun = FieldInfo(alias="evaluationRun")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["LabelDatasetJobCreateResponse"]


class LabelDatasetJobCreateResponse(BaseModel):
    job_id: str = FieldInfo(alias="jobId")
